@@ -1,13 +1,12 @@
 package Net::DNS;
 
-#
-# $Id: DNS.pm 1581 2017-06-26 11:46:03Z willem $
-#
-require 5.006;
+use strict;
+use warnings;
+
 our $VERSION;
-$VERSION = '1.11';
-$VERSION = eval $VERSION;
-our $SVNVERSION = (qw$LastChangedRevision: 1581 $)[1];
+$VERSION = '1.29';
+$VERSION = eval { $VERSION };
+our $SVNVERSION = (qw$Id: DNS.pm 1826 2020-11-18 13:18:18Z willem $)[2];
 
 
 =head1 NAME
@@ -24,15 +23,12 @@ Net::DNS is a collection of Perl modules that act as a Domain Name System
 (DNS) resolver. It allows the programmer to perform DNS queries that are
 beyond the capabilities of "gethostbyname" and "gethostbyaddr".
 
-The programmer should be somewhat familiar with the format of a DNS packet
-and its various sections. See RFC 1035 or DNS and BIND (Albitz & Liu) for
-details.
+The programmer should be familiar with the structure of a DNS packet.
+See RFC 1035 or DNS and BIND (Albitz & Liu) for details.
 
 =cut
 
 
-use strict;
-use warnings;
 use integer;
 
 use base qw(Exporter);
@@ -42,13 +38,13 @@ our @EXPORT = qw(SEQUENTIAL UNIXTIME YYYYMMDDxx
 
 
 local $SIG{__DIE__};
-require Net::DNS::RR;
-require Net::DNS::Packet;
-require Net::DNS::Update;
 require Net::DNS::Resolver;
+require Net::DNS::Packet;
+require Net::DNS::RR;
+require Net::DNS::Update;
 
 
-sub version { $VERSION; }
+sub version { return $VERSION; }
 
 
 #
@@ -61,10 +57,11 @@ sub version { $VERSION; }
 #
 sub rr {
 	my ($arg1) = @_;
-	my $res = ref($arg1) ? shift : new Net::DNS::Resolver();
+	my $res = ref($arg1) ? shift : Net::DNS::Resolver->new();
 
-	my $ans = $res->query(@_);
-	my @list = $ans ? $ans->answer : ();
+	my $reply = $res->query(@_);
+	my @list  = $reply ? $reply->answer : ();
+	return @list;
 }
 
 
@@ -89,7 +86,7 @@ sub mx {
 	# Then we return the list.
 
 	my @list = sort { $a->preference <=> $b->preference }
-			grep $_->type eq 'MX', &rr( @res, $name, 'MX', @class );
+			grep { $_->type eq 'MX' } &rr( @res, $name, 'MX', @class );
 	return @list;
 }
 
@@ -105,22 +102,23 @@ sub rrsort {
 	my ( $attribute, @rr ) = @_;	## NB: attribute is optional
 	( @rr, $attribute ) = @_ if ref($attribute) =~ /^Net::DNS::RR/;
 
-	my @extracted = grep $_->type eq $rrtype, @rr;
+	my @extracted = grep { $_->type eq $rrtype } @rr;
 	return @extracted unless scalar @extracted;
 	my $func   = "Net::DNS::RR::$rrtype"->get_rrsort_func($attribute);
 	my @sorted = sort $func @extracted;
+	return @sorted;
 }
 
 
 #
-# Auxiliary functions to support policy-driven zone serial numbering.
+# Auxilliary functions to support policy-driven zone serial numbering.
 #
 #	$successor = $soa->serial(SEQUENTIAL);
 #	$successor = $soa->serial(UNIXTIME);
 #	$successor = $soa->serial(YYYYMMDDxx);
 #
 
-sub SEQUENTIAL {undef}
+sub SEQUENTIAL { return (undef) }
 
 sub UNIXTIME { return CORE::time; }
 
@@ -131,19 +129,19 @@ sub YYYYMMDDxx {
 
 
 #
-# Auxiliary functions to support dynamic update.
+# Auxilliary functions to support dynamic update.
 #
 
 sub yxrrset {
-	my $rr = new Net::DNS::RR(@_);
+	my $rr = Net::DNS::RR->new(@_);
 	$rr->ttl(0);
 	$rr->class('ANY') unless $rr->rdata;
 	return $rr;
 }
 
 sub nxrrset {
-	my $rr = new Net::DNS::RR(@_);
-	new Net::DNS::RR(
+	my $rr = Net::DNS::RR->new(@_);
+	return Net::DNS::RR->new(
 		name  => $rr->name,
 		type  => $rr->type,
 		class => 'NONE'
@@ -151,9 +149,9 @@ sub nxrrset {
 }
 
 sub yxdomain {
-	my ( $domain, @etc ) = map split, @_;
-	my $rr = new Net::DNS::RR( scalar(@etc) ? @_ : ( name => $domain ) );
-	new Net::DNS::RR(
+	my ( $domain, @etc ) = map {split} @_;
+	my $rr = Net::DNS::RR->new( scalar(@etc) ? @_ : ( name => $domain ) );
+	return Net::DNS::RR->new(
 		name  => $rr->name,
 		type  => 'ANY',
 		class => 'ANY'
@@ -161,9 +159,9 @@ sub yxdomain {
 }
 
 sub nxdomain {
-	my ( $domain, @etc ) = map split, @_;
-	my $rr = new Net::DNS::RR( scalar(@etc) ? @_ : ( name => $domain ) );
-	new Net::DNS::RR(
+	my ( $domain, @etc ) = map {split} @_;
+	my $rr = Net::DNS::RR->new( scalar(@etc) ? @_ : ( name => $domain ) );
+	return Net::DNS::RR->new(
 		name  => $rr->name,
 		type  => 'ANY',
 		class => 'NONE'
@@ -171,14 +169,14 @@ sub nxdomain {
 }
 
 sub rr_add {
-	my $rr = new Net::DNS::RR(@_);
+	my $rr = Net::DNS::RR->new(@_);
 	$rr->{ttl} = 86400 unless defined $rr->{ttl};
 	return $rr;
 }
 
 sub rr_del {
-	my ( $domain, @etc ) = map split, @_;
-	my $rr = new Net::DNS::RR( scalar(@etc) ? @_ : ( name => $domain, type => 'ANY' ) );
+	my ( $domain, @etc ) = map {split} @_;
+	my $rr = Net::DNS::RR->new( scalar(@etc) ? @_ : ( name => $domain, type => 'ANY' ) );
 	$rr->class( $rr->rdata ? 'NONE' : 'ANY' );
 	$rr->ttl(0);
 	return $rr;
@@ -193,7 +191,7 @@ __END__
 =head2 Resolver Objects
 
 A resolver object is an instance of the L<Net::DNS::Resolver> class.
-A program can have multiple resolver objects, each maintaining its
+A program may have multiple resolver objects, each maintaining its
 own state information such as the nameservers to be queried, whether
 recursion is desired, etc.
 
@@ -201,46 +199,46 @@ recursion is desired, etc.
 =head2 Packet Objects
 
 L<Net::DNS::Resolver> queries return L<Net::DNS::Packet> objects.
-Packet objects have five sections:
+A packet object has five sections:
 
 =over 3
 
 =item *
 
-The header section, a L<Net::DNS::Header> object.
+header, represented by a L<Net::DNS::Header> object
 
 =item *
 
-The question section, a list of L<Net::DNS::Question> objects.
+question, a list of no more than one L<Net::DNS::Question> object
 
 =item *
 
-The answer section, a list of L<Net::DNS::RR> objects.
+answer, a list of L<Net::DNS::RR> objects
 
 =item *
 
-The authority section, a list of L<Net::DNS::RR> objects.
+authority, a list of L<Net::DNS::RR> objects
 
 =item *
 
-The additional section, a list of L<Net::DNS::RR> objects.
+additional, a list of L<Net::DNS::RR> objects
 
 =back
 
 =head2 Update Objects
 
 L<Net::DNS::Update> is a subclass of L<Net::DNS::Packet>
-used to create dynamic update requests.
+useful for creating dynamic update requests.
 
-=head2 Header Objects
+=head2 Header Object
 
-L<Net::DNS::Header> objects represent the header
-section of a DNS packet.
+The L<Net::DNS::Header> object mediates access to the header data
+which resides within the corresponding L<Net::DNS::Packet>.
 
-=head2 Question Objects
+=head2 Question Object
 
-L<Net::DNS::Question> objects represent the content of the question
-section of a DNS packet.
+The L<Net::DNS::Question> object represents the content of the question
+section of the DNS packet.
 
 =head2 RR Objects
 
@@ -253,10 +251,12 @@ The type of an RR object must be checked before calling any methods.
 
 =head1 METHODS
 
-See the manual pages listed above for other class-specific methods.
+Net::DNS exports methods and auxilliary functions to support
+DNS updates, zone serial number management, and simple DNS queries.
 
 =head2 version
 
+    use Net::DNS;
     print Net::DNS->version, "\n";
 
 Returns the version of Net::DNS.
@@ -267,14 +267,14 @@ Returns the version of Net::DNS.
     # Use a default resolver -- can not get an error string this way.
     use Net::DNS;
     my @rr = rr("example.com");
-    my @rr = rr("example.com", "A");
-    my @rr = rr("example.com", "A", "IN");
+    my @rr = rr("example.com", "AAAA");
+    my @rr = rr("example.com", "AAAA", "IN");
 
     # Use your own resolver object.
     my $res = Net::DNS::Resolver->new;
     my @rr  = rr($res, "example.com" ... );
 
-    my ($ptr) = rr("192.0.2.1");
+    my ($ptr) = rr("2001:DB8::dead:beef");
 
 The C<rr()> method provides simple RR lookup for scenarios where
 the full flexibility of Net::DNS is not required.
@@ -300,14 +300,18 @@ records for the specified name.
 The list will be sorted by preference.
 Returns an empty list if the query failed or no MX record was found.
 
-This method does not look up A records; it only performs MX queries.
+This method does not look up address records; it resolves MX only.
 
 
 =head1 Dynamic DNS Update Support
 
-The Net::DNS module provides auxiliary functions which support
+The Net::DNS module provides auxilliary functions which support
 dynamic DNS update requests.
 
+    $update = Net::DNS::Update->new( 'example.com' );
+
+    $update->push( prereq => nxrrset('example.com. AAAA') );
+    $update->push( update => rr_add('example.com. 86400 AAAA 2001::DB8::F00') );
 
 =head2 yxrrset
 
@@ -316,13 +320,12 @@ update packet.	There are two forms, value-independent and
 value-dependent:
 
     # RRset exists (value-independent)
-    $update->push(pre => yxrrset("host.example.com A"));
+    $update->push( pre => yxrrset("host.example.com AAAA") );
 
-Meaning:  At least one RR with the specified name and type must
-exist.
+Meaning:  At least one RR with the specified name and type must exist.
 
     # RRset exists (value-dependent)
-    $update->push(pre => yxrrset("host.example.com A 10.1.2.3"));
+    $update->push( pre => yxrrset("host.example.com AAAA 2001:DB8::1") );
 
 Meaning:  At least one RR with the specified name and type must
 exist and must have matching data.
@@ -335,7 +338,7 @@ be created.
 Use this method to add an "RRset does not exist" prerequisite to
 a dynamic update packet.
 
-    $update->push(pre => nxrrset("host.example.com A"));
+    $update->push( pre => nxrrset("host.example.com AAAA") );
 
 Meaning:  No RRs with the specified name and type can exist.
 
@@ -347,7 +350,7 @@ be created.
 Use this method to add a "name is in use" prerequisite to a dynamic
 update packet.
 
-    $update->push(pre => yxdomain("host.example.com"));
+    $update->push( pre => yxdomain("host.example.com") );
 
 Meaning:  At least one RR with the specified name must exist.
 
@@ -359,7 +362,7 @@ be created.
 Use this method to add a "name is not in use" prerequisite to a
 dynamic update packet.
 
-    $update->push(pre => nxdomain("host.example.com"));
+    $update->push( pre => nxdomain("host.example.com") );
 
 Meaning:  No RR with the specified name can exist.
 
@@ -370,7 +373,7 @@ be created.
 
 Use this method to add RRs to a zone.
 
-    $update->push(update => rr_add("host.example.com A 10.1.2.3"));
+    $update->push( update => rr_add("host.example.com AAAA 2001:DB8::c001:a1e") );
 
 Meaning:  Add this RR to the zone.
 
@@ -387,19 +390,19 @@ Use this method to delete RRs from a zone.  There are three forms:
 delete all RRsets, delete an RRset, and delete a specific RR.
 
     # Delete all RRsets.
-    $update->push(update => rr_del("host.example.com"));
+    $update->push( update => rr_del("host.example.com") );
 
 Meaning:  Delete all RRs having the specified name.
 
     # Delete an RRset.
-    $update->push(update => rr_del("host.example.com A"));
+    $update->push( update => rr_del("host.example.com AAAA") );
 
 Meaning:  Delete all RRs having the specified name and type.
 
     # Delete a specific RR.
-    $update->push(update => rr_del("host.example.com A 10.1.2.3"));
+    $update->push( update => rr_del("host.example.com AAAA 2001:DB8::dead:beef") );
 
-Meaning:  Delete all RRs having the specified name, type, and data.
+Meaning:  Delete the RR which matches the specified argument.
 
 RR objects created by this method should be added to the "update"
 section of a dynamic update packet.
@@ -410,9 +413,12 @@ be created.
 
 =head1 Zone Serial Number Management
 
-The Net::DNS module provides auxiliary functions which support
+The Net::DNS module provides auxilliary functions which support
 policy-driven zone serial numbering regimes.
 
+    $soa->serial(SEQUENTIAL);
+    $soa->serial(YYYMMDDxx);
+
 =head2 SEQUENTIAL
 
     $successor = $soa->serial( SEQUENTIAL );
@@ -431,7 +437,7 @@ elapsed since the previous update is less than one second.
 
     $successor = $soa->serial( YYYYMMDDxx );
 
-The 32 bit value returned by the auxiliary C<YYYYMMDDxx()> function
+The 32 bit value returned by the auxilliary C<YYYYMMDDxx()> function
 will be used as the base for the date-coded zone serial number.
 Serial number increments must be limited to 100 per day for the
 date information to remain useful.
@@ -441,7 +447,7 @@ date information to remain useful.
 =head1 Sorting of RR arrays
 
 C<rrsort()> provides functionality to help you sort RR arrays. In most cases
-this will give you the answer that you want, but you can specify your
+this will give you the result that you expect, but you can specify your
 own sorting method by using the C<< Net::DNS::RR::FOO->set_rrsort_func() >>
 class method. See L<Net::DNS::RR> for details.
 
@@ -492,7 +498,7 @@ See L<Net::DNS::Update> for an example of performing dynamic updates.
 
     use Net::DNS;
     my $res   = Net::DNS::Resolver->new;
-    my $reply = $res->search("www.example.com", "A");
+    my $reply = $res->search("www.example.com", "AAAA");
 
     if ($reply) {
 	foreach my $rr ($reply->answer) {
@@ -571,10 +577,10 @@ See L<Net::DNS::Update> for an example of performing dynamic updates.
     my $res    = Net::DNS::Resolver->new;
     $res->udp_timeout(10);
     $res->tcp_timeout(20);
-    my $socket = $res->bgsend("host.example.com");
+    my $socket = $res->bgsend("host.example.com", "AAAA");
 
     while ( $res->bgbusy($socket) ) {
-	# do some work here while waiting for the answer
+	# do some work here while waiting for the response
 	# ...and some more here
     }
 
